@@ -1257,8 +1257,8 @@ def _start(client, bot):
 			def remember(text):
 				bot._nowcmd=text
 				return True
-			if any([message.content[:len(max(bot._cmds, key=len))].startswith(await replaces(bot._codes["command"][cmd]["prefix"], message, message.guild, message.content, message, {}, 0, message.author)+await replaces(bot._codes["command"][cmd]["name"], message, message.guild, message.content, message, {}, 0, message.author)) and remember(cmd) for cmd in bot._codes["command"]]):
-				await use(message, bot._nowcmd, bot._codes["command"][bot._nowcmd]["prefix"]+bot._codes["command"][bot._nowcmd]["name"], "command")
+			if any([message.content[:len(max(bot._cmds, key=len))].startswith(get_vars(bot._codes["command"][cmd]["prefix"].replace("$authorID",str(message.author.id)).replace("$serverID",str(message.guild.id)), message.guild, {})+get_vars(bot._codes["command"][cmd]["name"].replace("$authorID",str(message.author.id)).replace("$serverID",str(message.guild.id)), message.guild, {})) and remember(cmd) for cmd in bot._codes["command"]]):
+				await use(message, bot._nowcmd, get_vars(bot._codes["command"][bot._nowcmd]["prefix"].replace("$authorID",str(message.author.id)).replace("$serverID",str(message.guild.id)), message.guild, {})+get_vars(bot._codes["command"][bot._nowcmd]["name"].replace("$authorID",str(message.author.id)).replace("$serverID",str(message.guild.id)), message.guild, {}), "command")
 	if bot._self:
 		client.run(bot._token, bot=False)
 	else:
